#include "dacme.h"
/*#include <ifaddrs.h>*/
#include <netinet/ip.h>

int read_int(int fd) {
    int auxint, retval;

    retval = read(fd, (char *)&auxint, sizeof(int));

    if(retval == -1) {
        fprintf(stderr,"Error al leer entero\n");
        exit(-1);
    }

    return ntohl(auxint);

}

int write_string(int fd, char *string) {
    int tam;

    tam = strlen(string);

    if ( write(fd, string, (tam)*sizeof(char)) == -1) {
        fprintf(stderr, "Write error on %d fd, Errno = %d\n", fd, errno);
        return -1;
    }

    return tam;
}

/*
 * Prints a flow to a string
 */
int sprintflow(char *buffer, flow *f) {

    return sprintf(buffer,"%s %d %d %d %d %d %d %d %d\n",f->ip, f->send_port, f->port, f->category, f->bitrate,f->packet_size, f->delay, f->jitter, f->status);

}

int check_flow(flow *f) {
    char buffer[1000];
    struct sockaddr_in server;
    struct hostent *Host;
    int tam, resul;
    int sock;

    buffer[0] = '4';
    sprintflow(&(buffer[1]), f);
    tam = strlen(buffer);

    sock = socket(AF_INET,SOCK_STREAM,0);
    if(sock == -1) {
        fprintf(stderr,"Error creating comunication socket\n");
        return -1;
    }

    Host = gethostbyname("localhost");
    if(Host == NULL) {
        fprintf(stderr,"Error, unable to resolve \"localhost\"\n");
        return -1;
    }

    server.sin_family = AF_INET;
    server.sin_addr.s_addr = ((struct in_addr *)(Host->h_addr))->s_addr;
    server.sin_port = htons(DACME_PORT);

    if (connect (sock, (struct sockaddr *)&server,sizeof (server)) == -1)
    {
            fprintf (stderr,"Error connecting Dacme Server\n");
    }

    write_string(sock,buffer);
    resul = read_int(sock);

    close(sock);

    if(resul == -1)
        return FALSE;
    else
        return TRUE;
}

int delete_flow(flow * f) {
    char buffer[1000];
    struct sockaddr_in server;
    struct hostent *Host;
    int tam, resul;
    int sock;

    buffer[0] = '2';
    sprintflow(&(buffer[1]), f);
    tam = strlen(buffer);

    sock = socket(AF_INET,SOCK_STREAM,0);
    if(sock == -1) {
        printf("Error creating comunication socket\n");
        return -1;
    }

    Host = gethostbyname("localhost");
    if(Host == NULL) {
        printf("Error, unable to resolve \"localhost\"\n");
        return -1;
    }

    server.sin_family = AF_INET;
    server.sin_addr.s_addr = ((struct in_addr *)(Host->h_addr))->s_addr;
    server.sin_port = htons(DACME_PORT);

    if (connect (sock, (struct sockaddr *)&server,sizeof (server)) == -1)
    {
            printf ("Error connecting Dacme Server\n");
    }

    write_string(sock,buffer);
    resul = read_int(sock);
    
    close(sock);

    if(resul == -1)
        return FALSE;
    else
        return TRUE;
}

int dacme_priority(int s, int category) {
  char cat;

  switch(category) {
  case 0:
    cat = 0x0; //BE
    break;
  case 1:
    cat = 0x08; //BK
    break;
  case 2:
    cat = 0x28; //VI
    break;    
  case 3:
    cat = 0x30; //VO
    break;
  default:
    cat = 0x0; //BE
  }
  cat = cat << 2;
  if(!setsockopt(s, IPPROTO_IP, IP_TOS, &cat, sizeof(cat))) {
    return TRUE;
  }
  
  return FALSE;
 
  
}

int dacme_socket(flow *f) {
    int retval, clientsize;
    struct sockaddr_in server;

    retval = socket(AF_INET,SOCK_DGRAM,0);
    if(retval == -1) {
        printf("Error, could not create socket\n");
        return -1;
    }
    if(dacme_priority(retval, f->category) == FALSE) {
      printf("Error, could not set priority\n");
      return -1;
    }

    server.sin_family = AF_INET;
    server.sin_port = htons(f->send_port);
    server.sin_addr.s_addr = INADDR_ANY;
    memset(&(server.sin_zero), '\0', 8);

    bind(retval, (struct sockaddr *)&server, sizeof(server));

    clientsize = sizeof (server);
    getsockname(retval, (struct sockaddr *) & server, &clientsize);
    f->send_port = ntohs(server.sin_port);

    if(check_flow(f) == -1) {
        close(retval);
        return -1;
    } else {
        return retval;
    }
}

int dacme_release(flow *f, int dacme_sock) {
    if(delete_flow(f) == TRUE) {
        close(dacme_sock);
        return TRUE;
    }
    return FALSE;
}

int init_flow(flow *f) {

    f->category = AC_VI;
    f->send_port = 0;
    f->port = 0;
    f->packet_size = 512;
    f->jitter = 0;
    f->bitrate = 0;
    f->delay = 0;

    return TRUE;
}
    
