/* 
 * File:   dacme_types.h
 * Author: alvaro
 *
 * Created on 6 de abril de 2009, 16:13
 */

#ifndef _DACME_TYPES_H
#define	_DACME_TYPES_H

#ifdef	__cplusplus
extern "C" {
#endif

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sys/time.h>

#define TRUE 1
#define FALSE 0

#define DACME_LISTEN_QUEUE_SIZE 50
#define DACME_TAM_BUFFER 1000

#define DACME_FIRST_SWAIT 0
#define DACME_FIRST_UWAIT 500000 //Half a second in usecs
#define DACME_ONE_SECOND 1000000 //One second in usecs

#define BW_PROBE_SIZE  10  //number of packets per BW probe
#define NUM_BW_PROBES  5  //total (maximum) number of BW probes
#define INTER_PROBE_TIME_SECONDS 3  //number of seconds between consecutive BW probe cycles
#define INTER_PROBE_TIME_USECONDS 0
#define PROBE_RESPONSE_TIME 0.5  //number of seconds between first probe packet and QoS reply
#define NUM_E2ED_PROBES 4 // total number of consecutive pings sent (1 worm-up + 3)
#define JIT_PROBE_DURATION  0.250 //250 miliseconds according to paper
#define DACME_MIN_BW_ARRIVALS 6
#define DACME_BW_RESERVE 512

#define DACME_E2ED_TAM_PROBE 3

#define DACME_EPSILON 3
#define DACME_TAU 50000.0 //50 ms in usecs

#define DACME_TAM_UDP_PROBE 2*DACME_TAM_BUFFER*DACME_TAM_BUFFER
#define DACME_TAM_UDP_REPLY sizeof(dacme_response)

#define MODE_UNKNOWN 0x0;
#define MODE_BW 0x1
#define MODE_E2ED 0x2
#define MODE_JIT 0x4

#define DACME_TIME_EXPIRED 1
#define DACME_TIME_LESS -1
#define DACME_TIME_EQUAL 0
#define DACME_TIME_HIGH 1


    typedef enum {B_PROBE, B_REPLY, E2ED_PROBE, E2ED_REPLY, JIT_PROBE, JIT_REPLY, B_PROBE_FAIL, E2ED_PROBE_FAIL, JIT_PROBE_FAIL, NOT_DEFINED} DACME_MSG_TYPE;
    typedef enum {AC_BE, AC_BK, AC_VI, AC_VO} AC;
    typedef enum { blocked, running } STATE;

    typedef struct _flow{
        char ip[16];
        int port;
        int send_port;
        int delay;
        AC category;
        int bitrate;
        int packet_size;
        int jitter;
        STATE status;
        struct timeval arrival;
    } flow;


    typedef struct _flow_node {
       flow *f;
       struct _flow_node *sig;
    } flow_node;

    typedef struct _probe_node {
        unsigned long ip;
        int port;

        int sequence_id;
        int probe_id;
        int packet_id;

        int mode;
        int sent;

        struct timeval first_arrival;
        struct timeval expiry;
        int arrivals;
        int packet_size;          //bytes

        unsigned int bandwidth_estimation; //bits/s
        int delay_estimation;     //ms
        int jitter_estimation;    //ms
    }probe_node;

    typedef struct _probe_list_node {
        probe_node *p;
        struct _probe_list_node *sig;
    }probe_list_node;

    typedef struct _dacme_response {
        DACME_MSG_TYPE msg_type;
        int sequence_id;
        int probe_id;
        unsigned int return_value;
    }dacme_response;

    typedef struct _dacme_test {
        DACME_MSG_TYPE msg_type;
        int mode;
        int sequence_id;
        int probe_id;
        int packet_id;
        int packet_size;
        int bandwhidth;
        int delay;
        int jitter;
    }dacme_test;

    typedef struct _dacme_age_node {
        flow_node *flow_list;
        struct _dacme_age_node *next;
    }dacme_age_node;


#ifdef	__cplusplus
}
#endif

#endif	/* _DACME_TYPES_H */

